==> signer-1.101.0-sources.jar: software/amazon/awscdk/services/signer/SigningProfileProps.java <==
package software.amazon.awscdk.services.signer;

/**
 * Construction properties for a Signing Profile object.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:19.630Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.SigningProfileProps")
@software.amazon.jsii.Jsii.Proxy(SigningProfileProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SigningProfileProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Signing Platform available for signing profile.
     * <p>
     * @see https://docs.aws.amazon.com/signer/latest/developerguide/gs-platform.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.signer.Platform getPlatform();

    /**
     * The validity period for signatures generated using this signing profile.
     * <p>
     * Default: - 135 months
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getSignatureValidity() {
        return null;
    }

    /**
     * Physical name of this Signing Profile.
     * <p>
     * Default: - Assigned by CloudFormation (recommended).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSigningProfileName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SigningProfileProps> {
        private software.amazon.awscdk.services.signer.Platform platform;
        private software.amazon.awscdk.core.Duration signatureValidity;
        private java.lang.String signingProfileName;

        /**
         * Sets the value of {@link SigningProfileProps#getPlatform}
         * @param platform The Signing Platform available for signing profile. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder platform(software.amazon.awscdk.services.signer.Platform platform) {
            this.platform = platform;
            return this;
        }

        /**
         * Sets the value of {@link SigningProfileProps#getSignatureValidity}
         * @param signatureValidity The validity period for signatures generated using this signing profile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signatureValidity(software.amazon.awscdk.core.Duration signatureValidity) {
            this.signatureValidity = signatureValidity;
            return this;
        }

        /**
         * Sets the value of {@link SigningProfileProps#getSigningProfileName}
         * @param signingProfileName Physical name of this Signing Profile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signingProfileName(java.lang.String signingProfileName) {
            this.signingProfileName = signingProfileName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SigningProfileProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SigningProfileProps build() {
            return new Jsii$Proxy(platform, signatureValidity, signingProfileName);
        }
    }

    /**
     * An implementation for {@link SigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SigningProfileProps {
        private final software.amazon.awscdk.services.signer.Platform platform;
        private final software.amazon.awscdk.core.Duration signatureValidity;
        private final java.lang.String signingProfileName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.platform = software.amazon.jsii.Kernel.get(this, "platform", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
            this.signatureValidity = software.amazon.jsii.Kernel.get(this, "signatureValidity", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
            this.signingProfileName = software.amazon.jsii.Kernel.get(this, "signingProfileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.signer.Platform platform, final software.amazon.awscdk.core.Duration signatureValidity, final java.lang.String signingProfileName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.platform = java.util.Objects.requireNonNull(platform, "platform is required");
            this.signatureValidity = signatureValidity;
            this.signingProfileName = signingProfileName;
        }

        @Override
        public final software.amazon.awscdk.services.signer.Platform getPlatform() {
            return this.platform;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getSignatureValidity() {
            return this.signatureValidity;
        }

        @Override
        public final java.lang.String getSigningProfileName() {
            return this.signingProfileName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("platform", om.valueToTree(this.getPlatform()));
            if (this.getSignatureValidity() != null) {
                data.set("signatureValidity", om.valueToTree(this.getSignatureValidity()));
            }
            if (this.getSigningProfileName() != null) {
                data.set("signingProfileName", om.valueToTree(this.getSigningProfileName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-signer.SigningProfileProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SigningProfileProps.Jsii$Proxy that = (SigningProfileProps.Jsii$Proxy) o;

            if (!platform.equals(that.platform)) return false;
            if (this.signatureValidity != null ? !this.signatureValidity.equals(that.signatureValidity) : that.signatureValidity != null) return false;
            return this.signingProfileName != null ? this.signingProfileName.equals(that.signingProfileName) : that.signingProfileName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.platform.hashCode();
            result = 31 * result + (this.signatureValidity != null ? this.signatureValidity.hashCode() : 0);
            result = 31 * result + (this.signingProfileName != null ? this.signingProfileName.hashCode() : 0);
            return result;
        }
    }
}

==> signer-1.174.0-sources.jar: software/amazon/awscdk/services/signer/SigningProfileProps.java <==
package software.amazon.awscdk.services.signer;

/**
 * Construction properties for a Signing Profile object.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * SigningProfile signingProfile = SigningProfile.Builder.create(this, "SigningProfile")
 *         .platform(Platform.AWS_LAMBDA_SHA384_ECDSA)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-21T22:31:00.803Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.SigningProfileProps")
@software.amazon.jsii.Jsii.Proxy(SigningProfileProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SigningProfileProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Signing Platform available for signing profile.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/signer/latest/developerguide/gs-platform.html">https://docs.aws.amazon.com/signer/latest/developerguide/gs-platform.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.signer.Platform getPlatform();

    /**
     * The validity period for signatures generated using this signing profile.
     * <p>
     * Default: - 135 months
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.Duration getSignatureValidity() {
        return null;
    }

    /**
     * Physical name of this Signing Profile.
     * <p>
     * Default: - Assigned by CloudFormation (recommended).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSigningProfileName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SigningProfileProps> {
        software.amazon.awscdk.services.signer.Platform platform;
        software.amazon.awscdk.core.Duration signatureValidity;
        java.lang.String signingProfileName;

        /**
         * Sets the value of {@link SigningProfileProps#getPlatform}
         * @param platform The Signing Platform available for signing profile. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder platform(software.amazon.awscdk.services.signer.Platform platform) {
            this.platform = platform;
            return this;
        }

        /**
         * Sets the value of {@link SigningProfileProps#getSignatureValidity}
         * @param signatureValidity The validity period for signatures generated using this signing profile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signatureValidity(software.amazon.awscdk.core.Duration signatureValidity) {
            this.signatureValidity = signatureValidity;
            return this;
        }

        /**
         * Sets the value of {@link SigningProfileProps#getSigningProfileName}
         * @param signingProfileName Physical name of this Signing Profile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder signingProfileName(java.lang.String signingProfileName) {
            this.signingProfileName = signingProfileName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SigningProfileProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SigningProfileProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SigningProfileProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SigningProfileProps {
        private final software.amazon.awscdk.services.signer.Platform platform;
        private final software.amazon.awscdk.core.Duration signatureValidity;
        private final java.lang.String signingProfileName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.platform = software.amazon.jsii.Kernel.get(this, "platform", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.signer.Platform.class));
            this.signatureValidity = software.amazon.jsii.Kernel.get(this, "signatureValidity", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
            this.signingProfileName = software.amazon.jsii.Kernel.get(this, "signingProfileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.platform = java.util.Objects.requireNonNull(builder.platform, "platform is required");
            this.signatureValidity = builder.signatureValidity;
            this.signingProfileName = builder.signingProfileName;
        }

        @Override
        public final software.amazon.awscdk.services.signer.Platform getPlatform() {
            return this.platform;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getSignatureValidity() {
            return this.signatureValidity;
        }

        @Override
        public final java.lang.String getSigningProfileName() {
            return this.signingProfileName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("platform", om.valueToTree(this.getPlatform()));
            if (this.getSignatureValidity() != null) {
                data.set("signatureValidity", om.valueToTree(this.getSignatureValidity()));
            }
            if (this.getSigningProfileName() != null) {
                data.set("signingProfileName", om.valueToTree(this.getSigningProfileName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-signer.SigningProfileProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SigningProfileProps.Jsii$Proxy that = (SigningProfileProps.Jsii$Proxy) o;

            if (!platform.equals(that.platform)) return false;
            if (this.signatureValidity != null ? !this.signatureValidity.equals(that.signatureValidity) : that.signatureValidity != null) return false;
            return this.signingProfileName != null ? this.signingProfileName.equals(that.signingProfileName) : that.signingProfileName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.platform.hashCode();
            result = 31 * result + (this.signatureValidity != null ? this.signatureValidity.hashCode() : 0);
            result = 31 * result + (this.signingProfileName != null ? this.signingProfileName.hashCode() : 0);
            return result;
        }
    }
}
